Discover Packages
github.com/CYPT71/platform-factory
internal
dockerarchive
package
Version:
v0.0.1
Opens a new window with list of versions in this module.
Published: Aug 17, 2026
License: MIT
Opens a new window with license information.
Imports: 10
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type Report struct {
Valid bool `json:"valid"`
Images int `json:"images"`
Layers int `json:"layers"`
Tags []string `json:"tags"`
}
Verify validates a Docker Save archive without extracting it or invoking a
container runtime. It accepts regular files only and verifies every
content-addressed config/layer name against its bytes.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.